# VK api dark library
PYTHON модуль для создания скриптов на основе VK_API

Установка:
```
python -m pip install -i https://test.pypi.org/simple/ vk-dark-library
```
Примеры:
[Примеры](https://github.com/DarkLorianPrime/vk_library/tree/dev/examples)
